@@ -1,5 +1,10 @@
 #pragma once
 
+// dont hook libc calls
+#define NO_XSLOCKS
+#define PERLIO_NOT_STDIO 0
+
+#define PERL_NO_GET_CONTEXT
 extern "C" {
 #  include "EXTERN.h"
 #  include "perl.h"
